@@ -1,9 +1,10 @@
 import sys, os, re
 import importlib.util
 
-from .apihelper import telegram # telebot.py
+from .apihelper import telegram
+from .autouser import client
 
-__all__ = ["telegram"]
+__all__ = ["telegram", "client"]
 
 def main():
     if len(sys.argv) > 1:
